Changelog — django-frontend-template 1.2.0 documentation

### Navigation

- index
- next |
- previous |
- django-frontend-template 1.2.0 documentation »

# Changelog

## 1.2.0

- Marked as inactive - no more updates.
- Updated djfrontend.py to match related projects.

## 1.1.0

- Updated djfrontend.py to match related projects.

## 1.0.0

- There was some wide-sweeping, non-backwards compatible changes - read carefully!
- Packaged renamed to djfrontend. This will affect INSTALLED_APPS settings.
- ‘djfrontend_template/base.html’ is now ‘djfrontend/base.html’.
- Template tags renamed to djfrontend.py.
- {% load djfrontend %} loads all template tags.
- Template tag djfrontend_html renamed to djfrontend_h5bp_html.

## 0.1.0

- Initial release

### Navigation

- index
- next |
- previous |
- django-frontend-template 1.2.0 documentation »